@@ -1,11 +1,15 @@
 """nginx plugin constants."""
-import pkg_resources
 import platform
 
+import pkg_resources
+
+FREEBSD_DARWIN_SERVER_ROOT = "/usr/local/etc/nginx"
+LINUX_SERVER_ROOT = "/etc/nginx"
+
 if platform.system() in ('FreeBSD', 'Darwin'):
-    server_root_tmp = "/usr/local/etc/nginx"
+    server_root_tmp = FREEBSD_DARWIN_SERVER_ROOT
 else:
-    server_root_tmp = "/etc/nginx"
+    server_root_tmp = LINUX_SERVER_ROOT
 
 CLI_DEFAULTS = dict(
     server_root=server_root_tmp,
